@@ -7,23 +7,23 @@
 #ifndef RESOURCESDATABASESCHEMA_H
 #define RESOURCESDATABASESCHEMA_H
 
-#include <QStringList>
 #include "../Database.h"
+#include <QStringList>
 
-namespace Common {
-namespace ResourcesDatabaseSchema {
+namespace Common
+{
+namespace ResourcesDatabaseSchema
+{
+QString version();
 
-    QString version();
+QStringList schema();
 
-    QStringList schema();
+QString path();
+void overridePath(const QString &path);
 
-    QString path();
-    void overridePath(const QString &path);
-
-    void initSchema(Database &database);
+void initSchema(Database &database);
 
 } // namespace ResourcesDatabase
 } // namespace Common
 
 #endif // RESOURCESDATABASESCHEMA_H
-
